@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Data::InputMonster;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 # ABSTRACT: consume data from multiple sources, best first; om nom nom!
 
@@ -68,9 +68,11 @@ sub consume {
       @sources = map { ("source_" . $i++) => $_ } @sources;
     }
 
+    my $input_arg = { field_name => $field_name };
+
     SOURCE: for (my $i = 0; $i < @sources; $i += 2) {
       my ($name, $getter) = @sources[ $i, $i + 1 ];
-      my $value = $getter->($self, $input);
+      my $value = $getter->($self, $input, $input_arg);
       next unless defined $value;
       if ($filter)  { $filter->()  for $value; }
       if ($checker) { $checker->() or next SOURCE for $value; }
@@ -110,7 +112,7 @@ Data::InputMonster - consume data from multiple sources, best first; om nom nom!
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -136,7 +138,8 @@ Sources may be given in one of two formats:
 In the second form, sources will be assigned unique names.
 
 The source value is a coderef which, handed the C<$input> argument to the
-C<consume> method, returns a candidate value (or undef).
+C<consume> method, returns a candidate value (or undef).  It is also handed a
+hashref of relevant information, most importantly C<field_name>.
 
 A filter is a coderef that works by altering C<$_>.
 
